Index: trunk/src/scriptbuilder/gui/ScriptBuilderFrame.java
===================================================================
--- trunk/src/scriptbuilder/gui/ScriptBuilderFrame.java	(revision 193)
+++ trunk/src/scriptbuilder/gui/ScriptBuilderFrame.java	(revision 207)
@@ -1840,5 +1840,4 @@
             script = new SimulationScript();
             script.loadScriptFromFile(fc.getSelectedFile());
-            script.saveFile = fc.getSelectedFile();
         }
         

Index: trunk/src/scriptbuilder/structures/SimulationScript.java
===================================================================
--- trunk/src/scriptbuilder/structures/SimulationScript.java	(revision 206)
+++ trunk/src/scriptbuilder/structures/SimulationScript.java	(revision 207)
@@ -18,4 +18,5 @@
 import java.nio.file.Paths;
 import java.util.TreeMap;
+import javax.swing.JOptionPane;
 import static scriptbuilder.structures.XMLBuilder.prettyPrintXML;
 
@@ -176,12 +177,12 @@
      * Load in an existing script from an XML file.
      *
-     * @param f the file containing the script
-     */
-    public void loadScriptFromFile(File f)
+     * @param infile the file containing the script
+     */
+    public void loadScriptFromFile(File infile)
     {
         try
         {
 
-            SAXParserFactory.newInstance().newSAXParser().parse(f, sh);
+            SAXParserFactory.newInstance().newSAXParser().parse(infile, sh);
 
             Vector<ScriptIncident> inc = sh.getIncidents();
@@ -191,13 +192,18 @@
                 addIncident(sci);
             }
+            saveFile = infile;
+
         }
         catch (Exception ex)
         {
-            System.out.println("ERROR LOADING SCRIPT");
-            ex.printStackTrace();
-        }
-        System.out.println("H");
-        for(Unit testUnit : units){
-            System.out.println(testUnit.toXML());
+            String errMsg = ex.getMessage();
+            if (ex.getMessage().endsWith(".dtd (No such file or directory)"))
+            {
+                errMsg += "\nThe required external DTD file must be placed in\n"
+                        + " the same folder as the xml file.";
+            }
+            JOptionPane.showMessageDialog(null, errMsg,
+                "Unable to load xml file",
+                JOptionPane.INFORMATION_MESSAGE);
         }
         this.update();